import { Store } from 'redux';
import { AnyT } from '../definitions.interface';
import { IApplicationSettings } from '../settings';
import { IChannel, IChannelClient } from './channel.interface';
import { PayloadWrapper } from './protocol';
import { IApplicationStoreEntity } from '../entities-definitions.interface';
export declare abstract class BaseChannel implements IChannel {
    private static logger;
    protected settings: IApplicationSettings;
    protected appStore: Store<IApplicationStoreEntity>;
    private clients;
    /**
     * @stable [21.05.2018]
     * @param {string} ip
     * @param {AnyT} config
     */
    abstract connect(ip: string, config?: AnyT): void;
    /**
     * @stable [21.05.2018]
     * @param ip
     */
    abstract disconnect(ip: any): void;
    /**
     * @stable [21.05.2018]
     * @param {string} ip
     * @param {IChannelClient} client
     */
    onConnect(ip: string, client: IChannelClient): void;
    /**
     * @stable [21.05.2018]
     * @param {string} ip
     * @param {IChannelClient} client
     */
    onDisconnect(ip: string, client: IChannelClient): void;
    /**
     * @stable [25.05.2018]
     * @param {string} ip
     * @param {IChannelClient} client
     * @param {string} name
     * @param {string} message
     */
    onMessage(ip: string, client: IChannelClient, name?: string, message?: string): void;
    /**
     * @stable [21.05.2018]
     * @param {string} ip
     * @param {string} event0
     * @param {AnyT} messages
     */
    emitEvent(ip: string, event0: string, ...messages: AnyT[]): void;
    /**
     * @stable [21.05.2018]
     * @param {string} ip
     * @param {AnyT} messages
     */
    emitChannelEvent(ip: string, messages: AnyT): void;
    /**
     * @stable [21.05.2018]
     * @param {string} ip
     * @param {PayloadWrapper} requestPayload
     */
    emitRequestPayload(ip: string, requestPayload: PayloadWrapper): void;
    /**
     * @stable [21.05.2018]
     * @param {string} ip
     * @param {IChannelClient} client
     */
    protected registerClient(ip: string, client: IChannelClient): void;
    /**
     * @stable [20.05.2018]
     * @param {string} ip
     */
    protected deregisterClient(ip: string): void;
    /**
     * @stable [21.05.2018]
     * @param {string} ip
     * @param {IChannelClient} client
     */
    protected registerChannelEvent(ip: string, client: IChannelClient): void;
    /**
     * @stable [21.05.2018]
     * @returns {string}
     */
    protected readonly eventToListen: string;
    /**
     * @stable [21.05.2018]
     * @returns {string}
     */
    protected readonly eventToEmit: string;
    /**
     * @stable [21.05.2018]
     * @param {string} message
     * @returns {AnyT}
     */
    private toMessage;
}
