"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
var inversify_1 = require("inversify");
var ts_smart_logger_1 = require("ts-smart-logger");
var R = require("ramda");
var util_1 = require("../util");
var definitions_interface_1 = require("../definitions.interface");
var di_1 = require("../di");
var channel_interface_1 = require("./channel.interface");
var BaseChannel = /** @class */ (function () {
    function BaseChannel() {
        this.clients = new Map();
    }
    BaseChannel_1 = BaseChannel;
    /**
     * @stable [21.05.2018]
     * @param {string} ip
     * @param {IChannelClient} client
     */
    BaseChannel.prototype.onConnect = function (ip, client) {
        this.onMessage(ip, client, channel_interface_1.CHANNEL_CONNECT_MESSAGE);
        BaseChannel_1.logger.info("[$BaseChannel][onConnect] Client has been connected successfully. Ip: " + ip);
    };
    /**
     * @stable [21.05.2018]
     * @param {string} ip
     * @param {IChannelClient} client
     */
    BaseChannel.prototype.onDisconnect = function (ip, client) {
        this.onMessage(ip, client, channel_interface_1.CHANNEL_DISCONNECT_MESSAGE);
        BaseChannel_1.logger.info("[$BaseChannel][onDisconnect] Client has been disconnected. Ip: " + ip);
    };
    /**
     * @stable [25.05.2018]
     * @param {string} ip
     * @param {IChannelClient} client
     * @param {string} name
     * @param {string} message
     */
    BaseChannel.prototype.onMessage = function (ip, client, name, message) {
        BaseChannel_1.logger.info(function () { return "[$BaseChannel][onMessage] Client received the message " + (message && JSON.stringify(message) ||
            '[-]') + ". Ip: " + ip + ", name: " + (name || '[-]'); });
        var payload = { ip: ip, name: name, data: this.toMessage(message) };
        this.appStore.dispatch({
            type: channel_interface_1.$CHANNEL_MESSAGE_ACTION_TYPE,
            data: util_1.defValuesFilter(payload),
        });
    };
    /**
     * @stable [21.05.2018]
     * @param {string} ip
     * @param {string} event0
     * @param {AnyT} messages
     */
    BaseChannel.prototype.emitEvent = function (ip, event0) {
        var messages = [];
        for (var _i = 2; _i < arguments.length; _i++) {
            messages[_i - 2] = arguments[_i];
        }
        var client = this.clients.get(ip);
        if (!client) {
            throw new Error("The client " + ip + " doesn't exist!");
        }
        BaseChannel_1.logger.debug(function () { return "[$BaseChannel][emitEvent] Client sent the messages " + (messages || '[-]') + ". Ip: " + ip + ", event: " + event0; });
        client.emit.apply(client, [event0].concat(messages));
    };
    /**
     * @stable [21.05.2018]
     * @param {string} ip
     * @param {AnyT} messages
     */
    BaseChannel.prototype.emitChannelEvent = function (ip, messages) {
        this.emitEvent(ip, this.eventToEmit, messages);
    };
    /**
     * @stable [21.05.2018]
     * @param {string} ip
     * @param {PayloadWrapper} requestPayload
     */
    BaseChannel.prototype.emitRequestPayload = function (ip, requestPayload) {
        this.emitChannelEvent(ip, JSON.stringify(requestPayload));
    };
    /**
     * @stable [21.05.2018]
     * @param {string} ip
     * @param {IChannelClient} client
     */
    BaseChannel.prototype.registerClient = function (ip, client) {
        var _this = this;
        this.clients.set(ip, client);
        client.on('connect', function () { return _this.onConnect(ip, client); });
        client.on('disconnect', function () { return _this.onDisconnect(ip, client); });
        this.registerChannelEvent(ip, client);
    };
    /**
     * @stable [20.05.2018]
     * @param {string} ip
     */
    BaseChannel.prototype.deregisterClient = function (ip) {
        var client = this.clients.get(ip);
        if (!client) {
            return;
        }
        client.close();
    };
    /**
     * @stable [21.05.2018]
     * @param {string} ip
     * @param {IChannelClient} client
     */
    BaseChannel.prototype.registerChannelEvent = function (ip, client) {
        var _this = this;
        client.on(this.eventToListen, function (message) { return _this.onMessage(ip, client, definitions_interface_1.UNDEF, message); });
    };
    Object.defineProperty(BaseChannel.prototype, "eventToListen", {
        /**
         * @stable [21.05.2018]
         * @returns {string}
         */
        get: function () {
            return this.settings.channel.eventToListen;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(BaseChannel.prototype, "eventToEmit", {
        /**
         * @stable [21.05.2018]
         * @returns {string}
         */
        get: function () {
            return this.settings.channel.eventToEmit;
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @stable [21.05.2018]
     * @param {string} message
     * @returns {AnyT}
     */
    BaseChannel.prototype.toMessage = function (message) {
        if (R.isNil(message)) {
            return message;
        }
        try {
            return JSON.parse(message);
        }
        catch (e) {
            return message;
        }
    };
    var BaseChannel_1;
    BaseChannel.logger = ts_smart_logger_1.LoggerFactory.makeLogger('BaseChannel');
    __decorate([
        di_1.lazyInject(di_1.DI_TYPES.Settings),
        __metadata("design:type", Object)
    ], BaseChannel.prototype, "settings", void 0);
    __decorate([
        di_1.lazyInject(di_1.DI_TYPES.Store),
        __metadata("design:type", Object)
    ], BaseChannel.prototype, "appStore", void 0);
    BaseChannel = BaseChannel_1 = __decorate([
        inversify_1.injectable()
    ], BaseChannel);
    return BaseChannel;
}());
exports.BaseChannel = BaseChannel;
//# sourceMappingURL=base-channel.service.js.map