"use strict";
var __assign = (this && this.__assign) || Object.assign || function(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
        s = arguments[i];
        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
            t[p] = s[p];
    }
    return t;
};
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
var R = require("ramda");
var inversify_1 = require("inversify");
var google_libphonenumber_1 = require("google-libphonenumber");
var di_1 = require("../../di");
var util_1 = require("../../util");
var NumberConverter = /** @class */ (function () {
    /**
     * @stable [22.10.2018]
     */
    function NumberConverter() {
        this.defaultFormatter = new Intl.NumberFormat();
        this.phoneUtilInstance = google_libphonenumber_1.PhoneNumberUtil.getInstance();
        /**
         * @stable [22.10.2018]
         */
        this.defaultCurrencyFormatOptions = { style: 'currency', currency: this.settings.currency.uiCurrency };
        this.currencyFormatter = new Intl.NumberFormat(this.uiLocale, this.defaultCurrencyFormatOptions);
        /**
         * @stable [22.10.2018]
         */
        this.defaultIntegerFormatOptions = {
            maximumFractionDigits: 0,
            minimumFractionDigits: 0,
        };
        this.integerFormatter = new Intl.NumberFormat(this.uiLocale, this.defaultIntegerFormatOptions);
        /**
         * @stable [22.10.2018]
         */
        this.defaultFractionalFormatOptions = {
            maximumFractionDigits: 2,
            minimumFractionDigits: 2,
        };
        this.fractionalFormatter = new Intl.NumberFormat(this.uiLocale, this.defaultFractionalFormatOptions);
        /**
         * @stable [22.10.2018]
         */
        this.defaultIntegerCurrencyFormatOptions = __assign({}, this.defaultCurrencyFormatOptions, this.defaultIntegerFormatOptions);
        this.integerCurrencyFormatter = new Intl.NumberFormat(this.uiLocale, this.defaultIntegerCurrencyFormatOptions);
        this.id = this.id.bind(this);
        this.format = this.format.bind(this);
        this.currency = this.currency.bind(this);
        this.formatAsInteger = this.formatAsInteger.bind(this);
        this.formatAsFractional = this.formatAsFractional.bind(this);
    }
    /**
     * @stable [28.09.2018]
     * @param {StringNumberT} value
     * @param {number} radix
     * @returns {StringNumberT}
     */
    NumberConverter.prototype.integer = function (value, radix) {
        if (radix === void 0) { radix = 10; }
        if (util_1.isNumber(value)) {
            return value;
        }
        var valueAsString = value;
        var result = parseInt(valueAsString, radix);
        return isNaN(result) ? value : result;
    };
    NumberConverter.prototype.number = function (value, stringResult) {
        if (stringResult === void 0) { stringResult = true; }
        if (util_1.isNumber(value)) {
            return value;
        }
        var valueAsString = value;
        var result = parseFloat(valueAsString);
        return isNaN(result) || (!R.equals(String(result), value) && stringResult) ? value : result;
    };
    NumberConverter.prototype.format = function (value, formatter) {
        if (formatter === void 0) { formatter = this.defaultFormatter; }
        return formatter.format(this.number(value));
    };
    NumberConverter.prototype.integerCurrency = function (value) {
        return this.integerCurrencyFormatter.format(this.number(value));
    };
    /**
     * @stable [22.10.2018]
     * @param {StringNumberT} value
     * @returns {string}
     */
    NumberConverter.prototype.formatAsInteger = function (value) {
        return this.integerFormatter.format(this.number(value, false));
    };
    /**
     * @stable [22.10.2018]
     * @param {StringNumberT} value
     * @returns {string}
     */
    NumberConverter.prototype.formatAsFractional = function (value) {
        return this.fractionalFormatter.format(this.number(value, false));
    };
    NumberConverter.prototype.currency = function (value, options) {
        if (options) {
            var currencyFormatter0 = new Intl.NumberFormat(this.uiLocale, __assign({}, this.defaultCurrencyFormatOptions, options));
            return this.format(value, currencyFormatter0);
        }
        return this.format(value, this.currencyFormatter);
    };
    /**
     * @stable [01.09.2018]
     * @param {EntityIdT} value
     * @returns {string}
     */
    NumberConverter.prototype.id = function (value) {
        return "#" + value;
    };
    /**
     * @stable [01.09.2018]
     * @param {EntityIdT} value
     * @returns {string}
     */
    NumberConverter.prototype.internalId = function (value) {
        return "(#" + value + ")";
    };
    NumberConverter.prototype.phone = function (value, phoneNumberFormat) {
        if (phoneNumberFormat === void 0) { phoneNumberFormat = google_libphonenumber_1.PhoneNumberFormat.INTERNATIONAL; }
        if (!value) {
            return '';
        }
        var v = util_1.isString(value) ? value : String(value);
        var phoneNumber;
        try {
            phoneNumber = this.phoneUtilInstance.parse(v, this.settings.phone.uiCountryAbbreviation);
        }
        catch (e) {
            return v;
        }
        return this.phoneUtilInstance.isValidNumber(phoneNumber)
            ? this.phoneUtilInstance.format(phoneNumber, phoneNumberFormat)
            : v;
    };
    Object.defineProperty(NumberConverter.prototype, "uiLocale", {
        /**
         * @stable [22.10.2018]
         * @returns {string}
         */
        get: function () {
            return this.settings.currency.uiLocale;
        },
        enumerable: true,
        configurable: true
    });
    __decorate([
        di_1.lazyInject(di_1.DI_TYPES.Settings),
        __metadata("design:type", Object)
    ], NumberConverter.prototype, "settings", void 0);
    NumberConverter = __decorate([
        inversify_1.injectable(),
        __metadata("design:paramtypes", [])
    ], NumberConverter);
    return NumberConverter;
}());
exports.NumberConverter = NumberConverter;
//# sourceMappingURL=number-converter.service.js.map