"use strict";
var __assign = (this && this.__assign) || Object.assign || function(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
        s = arguments[i];
        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
            t[p] = s[p];
    }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
var R = require("ramda");
var stack_interface_1 = require("./stack.interface");
var stack_helper_1 = require("./stack.helper");
function stackReducer(state, action) {
    if (state === void 0) { state = stack_interface_1.INITIAL_APPLICATION_STACK_STATE; }
    var stack = state.stack;
    switch (action.type) {
        case stack_interface_1.STACK_REMOVE_ACTION_TYPE:
            return __assign({}, state, { stack: stack_helper_1.destroySections(action.data, state) });
        case stack_interface_1.STACK_PUSH_ACTION_TYPE:
            return __assign({}, state, { stack: stack_helper_1.pushNextSection(action.data, state), needToDestroySections: null });
        case stack_interface_1.STACK_POP_ACTION_TYPE:
            var lock = state.lock;
            var lastEl = !lock ? R.last(stack) : null;
            var currentSection = action.data;
            return __assign({}, state, { lock: false }, (lock
                ? {} // If there is a lock - do nothing
                : {
                    stack: R.remove(stack.length - 1, 1, stack),
                }), { 
                // If the section has no lock - we must destroy it and its dependencies
                needToDestroySections: !lock
                    ? [currentSection].concat(lastEl ? lastEl.linkedToSections : [])
                    : null });
        case stack_interface_1.STACK_LOCK_ACTION_TYPE:
            var nextSection = action.data;
            return __assign({}, state, { lock: true, stack: stack_helper_1.lockNextSection(nextSection, state) });
    }
    return state;
}
exports.stackReducer = stackReducer;
//# sourceMappingURL=stack.reducer.js.map