import * as Promise from 'bluebird';
import { IJQueryElement } from '../definitions.interface';
import { IXYEntity } from '../entities-definitions.interface';
/**
 * @stable [14.06.2018]
 * @param {string} tag
 * @param {Element} parent
 * @returns {TElement}
 */
export declare const createElement: <TElement extends HTMLElement = HTMLElement>(tag?: string, parent?: Element) => TElement;
/**
 * @stable [21.11.2018]
 * @param {Partial<HTMLScriptElement>} cfg
 * @returns {Bluebird<HTMLScriptElement>}
 */
export declare const createScript: (cfg: Partial<HTMLScriptElement>) => Promise<HTMLScriptElement>;
/**
 * @stable [12.09.2018]
 * @param {{} | HTMLScriptElement} cfg
 * @param {string} libraries
 * @returns {Bluebird<HTMLScriptElement>}
 */
export declare const getGoogleMapsScript: (cfg?: {} | HTMLScriptElement, libraries?: string) => Promise<HTMLScriptElement>;
/**
 * @stable [30.07.2018]
 * @param {Element} element
 * @param {string} clsName
 */
export declare const addClassNameToElement: (element: Element, ...clsName: string[]) => void;
/**
 * @stable [30.10.2018]
 * @param {Element} element
 * @param {string} clsName
 */
export declare const removeClassNameFromElement: (element: Element, ...clsName: string[]) => void;
/**
 * @stable [01.10.2018]
 * @param {string} rootId
 */
export declare const addRootElement: (rootId: string) => void;
/**
 * @stable [14.11.2018]
 * @param {string} clsName
 */
export declare const addClassNameToBody: (...clsName: string[]) => void;
/**
 * @stable [28.06.2018]
 * @param {Element} child
 * @param {Element} parent
 * @returns {Element}
 */
export declare const addChild: (child: Element, parent?: Element) => Element;
/**
 * @stable [28.06.2018]
 * @param {Element} child
 * @param {Element} parent
 * @returns {Element}
 */
export declare const removeChild: (child: Element, parent?: Element) => Element;
/**
 * @stable [17.11.2018]
 * @param {Element} child
 * @param {Element} parent
 * @returns {Element}
 */
export declare const removeSelf: (child: Element, parent?: Element) => Element;
/**
 * @stable [14.06.2018]
 * @param {string} images
 */
export declare const createPreloadedImg: (...images: string[]) => void;
/**
 * @stable [04.10.2018]
 * @param {Element} source
 * @param {number | (() => number)} left
 * @param {number | (() => number)} top
 */
export declare const setAbsoluteOffsetByCoordinates: (source: Element, left: number | (() => number), top: number | (() => number)) => void;
/**
 * @stable [04.10.2018]
 * @param {Element} source
 * @param {string} style
 * @param {AnyT} value
 * @returns {any}
 */
export declare const applyStyle: (source: Element, style: string, value: any) => JQuery<Element>;
/**
 * @stable [04.10.2018]
 * @param {Element} source
 * @returns {number}
 */
export declare const getWidth: (source: Element) => number;
/**
 * @stable [18.11.2018]
 * @param {Element} source
 * @param {number} width
 * @returns {any}
 */
export declare const setWidth: (source: Element, width: number) => JQuery<Element>;
/**
 * @stable [27.10.2018]
 * @param {Element} source
 * @returns {number}
 */
export declare const getHeight: (source: Element) => number;
/**
 * @stable [27.10.2018]
 * @param {Element} source
 * @returns {number}
 */
export declare const getContentHeight: (source: Element) => number;
/**
 * @stable [01.12.2018]
 * @param {Element} source
 * @returns {number}
 */
export declare const getScrollLeft: (source: Element) => number;
/**
 * @stable [01.12.2018]
 * @param {Element} source
 * @returns {number}
 */
export declare const getScrollTop: (source: Element) => number;
/**
 * @stable [01.12.2018]
 * @param {Element} source
 * @param {number} value
 * @returns {IJQueryElement}
 */
export declare const setScrollTop: (source: Element, value: number) => IJQueryElement<Element>;
/**
 * @stable [04.10.2018]
 * @param {Element} source
 * @returns {boolean}
 */
export declare const isParentDocumentBody: (source: Element) => boolean;
/**
 * @stable [23.06.2018]
 * @returns {boolean}
 */
export declare const isDocumentHasFocus: () => boolean;
/**
 * @stable [28.06.2018]
 * @param {string} fileName
 * @param {Blob} blob
 */
export declare const downloadFile: (fileName: string, blob: Blob) => void;
/**
 * @stable [12.09.2018]
 * @param {string} path
 * @param {string} target
 */
export declare const downloadAnchoredFile: (path: string, target?: string) => void;
/**
 * @stable [03.09.2018]
 * @param {HTMLElement} el
 * @returns {boolean}
 */
export declare const isElementFocused: (el: HTMLElement) => boolean;
/**
 * @stable [19.09.2018]
 * @param {string} v
 * @returns {number}
 */
export declare const parseValueAtPx: (v: string) => number;
/**
 * @stable [30.07.2018]
 * @returns {() => boolean}
 */
export declare const preventContextMenu: () => () => boolean;
/**
 * @stable [01.12.2018]
 * @param {string} selector
 * @param {Element} parent
 * @returns {Element}
 */
export declare const findElement: (selector: string, parent?: Element) => Element;
/**
 * @stable [01.12.2018]
 * @param {Element} parent
 * @returns {Element}
 */
export declare const findUniversalSelectedElement: (parent?: Element) => Element;
/**
 * @stable [01.12.2018]
 * @param {Element} element
 * @param {IXYEntity} xyEntity
 */
export declare const scrollTo: (element: Element, xyEntity: IXYEntity) => void;
